"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = __importDefault(require("./logger"));
const fs_1 = __importDefault(require("fs"));
function loadAllSites() {
    const sites = [];
    // reads all the files from the sites directory
    fs_1.default.readdirSync(`${__dirname}/sites`).forEach((site) => {
        // for each one, load it into the sites array
        logger_1.default.debug('loading site module: %s', site);
        sites.push(require(`./sites/${site}`));
    });
    // return all sites loaded
    return sites;
}
class SiteManager {
    sites;
    constructor() {
        logger_1.default.debug('initializing SiteManager');
        // first, load all the sites we have available
        this.sites = loadAllSites();
    }
    /**
     * Loads a Site that can handle the given URI. If no matches are found,
     * an Error is thrown.
     *
     * @param  {string} uri The URI for a website
     * @return {Site}     The Site which can handle the URI
     */
    loadSite(uri) {
        logger_1.default.debug('attempting to find site for uri: %s', uri);
        // loop over all our sites
        for (let i = 0; i < this.sites.length; i++) {
            const siteClass = this.sites[i];
            // if one matches...
            if (siteClass.isSite(uri)) {
                logger_1.default.debug('match found, using site: %s', siteClass.name);
                // return a new instance of it passing in the URI
                const Class = siteClass;
                return new Class(uri);
            }
        }
        // no sites were found to handle the given URI, throw an Error
        // (maybe some nice person will contribute code to handle this site :)
        throw new Error(`site not found for uri (please help contribute!): ${uri}`);
    }
}
exports.default = new SiteManager();
